@@ -31,3 +31,15 @@ def test__FakeHint__getattr() -> None:
     assert FakeHint(typing).Union.evaluate() == Union
     assert FakeHint(typing).Union.evaluate() == Union
     assert FakeHint(typing).List[FakeHint(int)].evaluate() == List[int]
+
+
+def test__FakeHint__Optional() -> None:
+    assert FakeHint(Optional)[FakeHint(int)].evaluate() == Optional[int]
+
+
+def test__FakeHint__callable() -> None:
+    assert FakeHint(int)("42").evaluate() == 42
+
+    with pytest.raises(RuntimeError) as excinfo:
+        FakeHint(Optional)[FakeHint(int)]("foobar")
+    assert str(excinfo.value) == "FakeHint(typing.Optional, args=(FakeHint(<class 'int'>, args=None),)) is not callable"
